@@ -1,6 +1,7 @@
-__version__ = '1.4.2'
+__version__ = '1.5'
 
 from redis import Redis
+from pyres.compat import string_types
 import pyres.json_parser as json
 
 import os
@@ -120,14 +121,6 @@ class ResQ(object):
 
         ``password`` -- The password, if required, of your Redis server. Default is "None".
 
-        ``timeout`` -- The timeout keyword is in the signature, but is unused. Default is "None".
-
-        ``retry_connection`` -- This keyword is in the signature but is deprecated. Default is "True".
-
-
-    Both ``timeout`` and ``retry_connection`` will be removed as the python-redis client
-    no longer uses them.
-
     Example usage::
 
         >>> from pyres import *
@@ -152,13 +145,13 @@ class ResQ(object):
         self.redis.rpush("resque:queue:%s" % queue, ResQ.encode(item))
 
     def pop(self, queues, timeout=10):
-        if isinstance(queues, basestring):
+        if isinstance(queues, string_types):
             queues = [queues]
         ret = self.redis.blpop(["resque:queue:%s" % q for q in queues],
                                timeout=timeout)
         if ret:
             key, ret = ret
-            return key[13:], ResQ.decode(ret)  # trim "resque:queue:"
+            return key[13:].decode(), ResQ.decode(ret)  # trim "resque:queue:"
         else:
             return None, None
 
@@ -186,7 +179,7 @@ class ResQ(object):
         return self._redis
 
     def _set_redis(self, server):
-        if isinstance(server, basestring):
+        if isinstance(server, string_types):
             self.dsn = server
             address, _, db = server.partition('/')
             host, port = address.split(':')
@@ -231,7 +224,10 @@ class ResQ(object):
             logger.debug("no arguments passed in.")
 
     def queues(self):
-        return self.redis.smembers("resque:queues") or []
+        return [sm.decode() for sm in self.redis.smembers("resque:queues")] or []
+
+    def workers(self):
+        return [w.decode() for w in self.redis.smembers("resque:workers")] or []
 
     def info(self):
         """Returns a dictionary of the current status of the pending jobs,
@@ -252,7 +248,7 @@ class ResQ(object):
         }
 
     def keys(self):
-        return [key.replace('resque:','')
+        return [key.decode().replace('resque:','')
                 for key in self.redis.keys('resque:*')]
 
     def reserve(self, queues):
@@ -262,10 +258,6 @@ class ResQ(object):
     def __str__(self):
         return "PyRes Client connected to %s" % self.dsn
 
-    def workers(self):
-        from pyres.worker import Worker
-        return Worker.all(self)
-
     def working(self):
         from pyres.worker import Worker
         return Worker.working(self)
@@ -312,7 +304,7 @@ class ResQ(object):
         size = 0
         length = self.redis.zcard('resque:delayed_queue_schedule')
         for i in self.redis.zrange('resque:delayed_queue_schedule',0,length):
-            size += self.delayed_timestamp_size(i)
+            size += self.delayed_timestamp_size(i.decode())
         return size
 
     def delayed_timestamp_size(self, timestamp):
@@ -322,11 +314,13 @@ class ResQ(object):
     def next_delayed_timestamp(self):
         key = int(time.mktime(ResQ._current_time().timetuple()))
         array = self.redis.zrangebyscore('resque:delayed_queue_schedule',
-                                         '-inf', key)
+                                         '-inf', key, start=0, num=1)
         timestamp = None
         if array:
             timestamp = array[0]
-        return timestamp
+
+        if timestamp:
+            return timestamp.decode()
 
     def next_item_for_timestamp(self, timestamp):
         #key = int(time.mktime(timestamp.timetuple()))
@@ -346,10 +340,10 @@ class ResQ(object):
 
     @classmethod
     def decode(cls, item):
-        if isinstance(item, basestring):
-            ret = json.loads(item)
-            return ret
-        return None
+        if not isinstance(item, string_types):
+            item = item.decode()
+        ret = json.loads(item)
+        return ret
 
     @classmethod
     def _enqueue(cls, klass, *args):
