@@ -10,8 +10,12 @@ import logging
 import logging.handlers
 from pyres import ResQ, Stat, get_logging_handler, special_log_file
 from pyres.exceptions import NoQueueError
-from pyres.utils import OrderedDict
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 from pyres.job import Job
+from pyres.compat import string_types
 import pyres.json_parser as json
 try:
     from setproctitle import setproctitle
@@ -20,7 +24,7 @@ except:
         pass
 
 def setup_logging(procname, namespace='', log_level=logging.INFO, log_file=None):
-    
+
     logger = multiprocessing.get_logger()
     #logger = multiprocessing.log_to_stderr()
     logger.setLevel(log_level)
@@ -29,63 +33,67 @@ def setup_logging(procname, namespace='', log_level=logging.INFO, log_file=None)
     return logger
 
 class Minion(multiprocessing.Process):
-    def __init__(self, queues, server, password, log_level=logging.INFO, log_path=None):
+    def __init__(self, queues, server, password, log_level=logging.INFO, log_path=None, interval=5, concat_logs=False,
+                 max_jobs=0):
         multiprocessing.Process.__init__(self, name='Minion')
-        
+
         #format = '%(asctime)s %(levelname)s %(filename)s-%(lineno)d: %(message)s'
         #logHandler = logging.StreamHandler()
         #logHandler.setFormatter(logging.Formatter(format))
         #self.logger = multiprocessing.get_logger()
         #self.logger.addHandler(logHandler)
         #self.logger.setLevel(logging.DEBUG)
-        
+
         self.queues = queues
         self._shutdown = False
         self.hostname = os.uname()[1]
         self.server = server
         self.password = password
-        
+        self.interval = interval
+
         self.log_level = log_level
         self.log_path = log_path
         self.log_file = None
-        
+        self.concat_logs = concat_logs
+        self.max_jobs = max_jobs
+
     def prune_dead_workers(self):
         pass
-    
+
     def schedule_shutdown(self, signum, frame):
         self._shutdown = True
-    
+
     def register_signal_handlers(self):
         signal.signal(signal.SIGTERM, self.schedule_shutdown)
         signal.signal(signal.SIGINT, self.schedule_shutdown)
         signal.signal(signal.SIGQUIT, self.schedule_shutdown)
-    
+
     def register_minion(self):
         self.resq.redis.sadd('resque:minions',str(self))
         self.started = datetime.datetime.now()
-    
+
     def startup(self):
         self.register_signal_handlers()
         self.prune_dead_workers()
         self.register_minion()
-    
+
     def __str__(self):
         return '%s:%s:%s' % (self.hostname, self.pid, ','.join(self.queues))
-    
+
     def reserve(self):
         self.logger.debug('checking queues: %s' % self.queues)
         job = Job.reserve(self.queues, self.resq, self.__str__())
         if job:
             self.logger.info('Found job on %s' % job._queue)
             return job
-    
+
     def process(self, job):
         if not job:
             return
         try:
             self.working_on(job)
             job.perform()
-        except Exception, e:
+        except Exception as e:
             exceptionType, exceptionValue, exceptionTraceback = sys.exc_info()
             self.logger.error("%s failed: %s" % (job, e))
             job.fail(exceptionTraceback)
@@ -95,7 +103,7 @@ class Minion(multiprocessing.Process):
             self.logger.info('completed job: %s' % job)
         finally:
             self.done_working()
-    
+
     def working_on(self, job):
         setproctitle('pyres_minion:%s: working on job: %s' % (os.getppid(), job._payload))
         self.logger.debug('marking as working on')
@@ -108,66 +116,78 @@ class Minion(multiprocessing.Process):
         self.resq.redis["resque:minion:%s" % str(self)] = data
         self.logger.debug("minion:%s" % str(self))
         #self.logger.debug(self.resq.redis["resque:minion:%s" % str(self)])
-    
+
     def failed(self):
         Stat("failed", self.resq).incr()
-    
+
     def processed(self):
         total_processed = Stat("processed", self.resq)
         total_processed.incr()
-    
+
     def done_working(self):
         self.logger.debug('done working')
         self.processed()
         self.resq.redis.delete("resque:minion:%s" % str(self))
-    
+
     def unregister_minion(self):
         self.resq.redis.srem('resque:minions',str(self))
         self.started = None
-    
+
     def work(self, interval=5):
-        
+
         self.startup()
+        cur_job = 0
         while True:
             setproctitle('pyres_minion:%s: waiting for job on: %s' % (os.getppid(),self.queues))
             self.logger.info('waiting on job')
             if self._shutdown:
                 self.logger.info('shutdown scheduled')
                 break
+            self.logger.debug('max_jobs: %d cur_jobs: %d' % (self.max_jobs, cur_job))
+            if (self.max_jobs > 0 and self.max_jobs < cur_job):
+                self.logger.debug('max_jobs reached on %s: %d' % (self.pid, cur_job))
+                self.logger.debug('minion sleeping for: %d secs' % interval)
+                time.sleep(interval)
+                cur_job = 0
             job = self.reserve()
             if job:
                 self.process(job)
+                cur_job = cur_job + 1
             else:
+                cur_job = 0
+                self.logger.debug('minion sleeping for: %d secs' % interval)
                 time.sleep(interval)
         self.unregister_minion()
-    
+
     def clear_logger(self):
         for handler in self.logger.handlers:
             self.logger.removeHandler(handler)
-    
+
     def run(self):
         setproctitle('pyres_minion:%s: Starting' % (os.getppid(),))
         if self.log_path:
             if special_log_file(self.log_path):
                 self.log_file = self.log_path
+            elif self.concat_logs:
+                self.log_file = os.path.join(self.log_path, 'minion.log')
             else:
                 self.log_file = os.path.join(self.log_path, 'minion-%s.log' % self.pid)
         namespace = 'minion:%s' % self.pid
         self.logger = setup_logging('minion', namespace, self.log_level, self.log_file)
         #self.clear_logger()
-        if isinstance(self.server,basestring):
+        if isinstance(self.server,string_types):
             self.resq = ResQ(server=self.server, password=self.password)
         elif isinstance(self.server, ResQ):
             self.resq = self.server
         else:
             raise Exception("Bad server argument")
-        
-        
-        self.work()
+
+
+        self.work(self.interval)
         #while True:
         #    job = self.q.get()
         #    print 'pid: %s is running %s ' % (self.pid,job)
-    
+
 
 class Khan(object):
     _command_map = {
@@ -175,7 +195,8 @@ class Khan(object):
         'REMOVE': '_remove_minion',
         'SHUTDOWN': '_schedule_shutdown'
     }
-    def __init__(self, pool_size=5, queues=[], server='localhost:6379', password=None, logging_level=logging.INFO, log_file=None):
+    def __init__(self, pool_size=5, queues=[], server='localhost:6379', password=None, logging_level=logging.INFO,
+            log_file=None, minions_interval=5, concat_minions_logs=False, max_jobs=0):
         #super(Khan,self).__init__(queues=queues,server=server,password=password)
         self._shutdown = False
         self.pool_size = int(pool_size)
@@ -189,28 +210,31 @@ class Khan(object):
         self.password = password
         self.logging_level = logging_level
         self.log_file = log_file
-        
+        self.minions_interval = minions_interval
+        self.concat_minions_logs = concat_minions_logs
+        self.max_jobs = max_jobs
+
         #self._workers = list()
-    
+
     def setup_resq(self):
         if hasattr(self,'logger'):
             self.logger.info('Connecting to redis server - %s' % self.server)
-        if isinstance(self.server,basestring):
+        if isinstance(self.server,string_types):
             self.resq = ResQ(server=self.server, password=self.password)
         elif isinstance(self.server, ResQ):
             self.resq = self.server
         else:
             raise Exception("Bad server argument")
-    
+
     def validate_queues(self):
         "Checks if a worker is given atleast one queue to work on."
         if not self.queues:
             raise NoQueueError("Please give each worker at least one queue.")
-    
+
     def startup(self):
         self.register_signal_handlers()
-        
-    
+
+
     def register_signal_handlers(self):
         signal.signal(signal.SIGTERM, self.schedule_shutdown)
         signal.signal(signal.SIGINT, self.schedule_shutdown)
@@ -252,23 +276,23 @@ class Khan(object):
 
     def _schedule_shutdown(self):
         self.schedule_shutdown(None, None)
-    
+
     def schedule_shutdown(self, signum, frame):
         self.logger.info('Khan Shutdown scheduled')
         self._shutdown = True
-    
+
     def kill_child(self, signum, frame):
         self._remove_minion()
-    
+
     def add_child(self, signum, frame):
         self.add_minion()
-    
+
     def register_khan(self):
         if not hasattr(self, 'resq'):
             self.setup_resq()
         self.resq.redis.sadd('resque:khans',str(self))
         self.started = datetime.datetime.now()
-    
+
     def _check_commands(self):
         if not self._shutdown:
             self.logger.debug('Checking commands')
@@ -277,7 +301,7 @@ class Khan(object):
             if command:
                 self.process_command(command)
                 self._check_commands()
-    
+
     def process_command(self, command):
         self.logger.info('Processing Command')
         #available commands, shutdown, add 1, remove 1
@@ -286,13 +310,13 @@ class Khan(object):
             fn = getattr(self, command_item)
             if fn:
                 fn()
-    
+
     def add_minion(self):
         self._add_minion()
         self.resq.redis.srem('resque:khans',str(self))
         self.pool_size += 1
         self.resq.redis.sadd('resque:khans',str(self))
-    
+
     def _add_minion(self):
         if hasattr(self,'logger'):
             self.logger.info('Adding minion')
@@ -303,13 +327,15 @@ class Khan(object):
                 log_path = os.path.dirname(self.log_file)
         else:
             log_path = None
-        m = Minion(self.queues, self.server, self.password, log_level=self.logging_level, log_path=log_path)
+        m = Minion(self.queues, self.server, self.password, interval=self.minions_interval,
+                   log_level=self.logging_level, log_path=log_path, concat_logs=self.concat_minions_logs,
+                   max_jobs=self.max_jobs)
         m.start()
         self._workers[m.pid] = m
         if hasattr(self,'logger'):
             self.logger.info('minion added at: %s' % m.pid)
         return m
-    
+
     def _shutdown_minions(self):
         """
         send the SIGNINT signal to each worker in the pool.
@@ -318,7 +344,7 @@ class Khan(object):
         for minion in self._workers.values():
             minion.terminate()
             minion.join()
-    
+
     def _remove_minion(self, pid=None):
         #if pid:
         #    m = self._workers.pop(pid)
@@ -328,20 +354,20 @@ class Khan(object):
         self.pool_size -= 1
         self.resq.redis.sadd('resque:khans',str(self))
         return m
-    
+
     def unregister_khan(self):
         if hasattr(self,'logger'):
             self.logger.debug('unregistering khan')
         self.resq.redis.srem('resque:khans',str(self))
         self.started = None
-    
+
     def setup_minions(self):
         for i in range(self.pool_size):
             self._add_minion()
 
     def _setup_logging(self):
         self.logger = setup_logging('khan', 'khan', self.logging_level, self.log_file)
-    
+
     def work(self, interval=2):
         setproctitle('pyres_manager: Starting')
         self.startup()
@@ -361,17 +387,21 @@ class Khan(object):
                 break
             #get job
             else:
+                self.logger.debug('manager sleeping for: %d secs' % interval)
                 time.sleep(interval)
         self.unregister_khan()
-    
+
     def __str__(self):
         hostname = os.uname()[1]
         return '%s:%s:%s' % (hostname, self.pid, self.pool_size)
-        
+
     @classmethod
-    def run(cls, pool_size=5, queues=[], server='localhost:6379', logging_level=logging.INFO, log_file=None):
-        worker = cls(pool_size=pool_size, queues=queues, server=server, logging_level=logging_level, log_file=log_file)
-        worker.work()
+    def run(cls, pool_size=5, queues=[], server='localhost:6379', password=None, interval=2,
+            logging_level=logging.INFO, log_file=None, minions_interval=5, concat_minions_logs=False, max_jobs=0):
+        worker = cls(pool_size=pool_size, queues=queues, server=server, password=password, logging_level=logging_level,
+                     log_file=log_file, minions_interval=minions_interval, concat_minions_logs=concat_minions_logs,
+                     max_jobs=max_jobs)
+        worker.work(interval=interval)
 
 #if __name__ == "__main__":
 #    k = Khan()
